@@ -1,19 +1,22 @@
 from investing_algorithm_framework.app.stateless.action_handlers \
     import ActionHandler
-from investing_algorithm_framework.app.stateless.action_handlers import Action
+from investing_algorithm_framework.app.stateless.action_handlers import \
+    StatelessAction
 from investing_algorithm_framework.app.stateless.exception_handler import \
     handle_exception
-from investing_algorithm_framework.core.exceptions import OperationalException
+from investing_algorithm_framework.domain.exceptions import \
+    OperationalException
 
 
 class StatelessHandler:
 
-    def handler(self, payload, context):
+    def handler(self, payload, algorithm):
         action = StatelessHandler.get_action_type(payload)
 
         try:
             # Handle the action
-            action_handler = ActionHandler.of(Action.from_string(action))
+            action_handler = ActionHandler.of(StatelessAction
+                                              .from_string(action))
             return action_handler.handle(payload)
         except Exception as e:
             return handle_exception(e)
